@@ -8,7 +8,7 @@ fn use_develop_debug() {
     let array = vec!["a", "b", "c"];
     let title2 = "balabala...";
 
-    develop_debug!(output true);
+    develop_debug!(output method);
     develop_debug!(title "example {}",title2);
     develop_debug!(step "do something...{}", say);
     develop_debug!(var x,say);
@@ -19,7 +19,6 @@ fn use_develop_debug() {
         "{}",
         "Use it just as you would with the `println!()` macro."
     );
-    develop_debug!(output false);
 }
 
 // Using the shortcut, print the same result as above.
@@ -41,5 +40,19 @@ fn use_develop_debug_shortcut() {
         "{}",
         "Use it just as you would with the `println!()` macro."
     );
-    dd____hide!();
 }
+
+#[test]
+fn use_output_range_control() {    
+    dd____show!(); // Output only messages for the current method
+    dd____step!("current method 1 .."); // output
+    other(); // ignored
+    dd____show!(global); // Outputs all messages for all methods
+    dd____step!("current method 2 .."); // output
+    other(); // output
+    dd____hide!(global);
+}
+
+fn other() {
+    dd____step!("other method");
+}
\ No newline at end of file
